@@ -36,7 +36,8 @@ class Spoke(ComponentResource):
 
         # Azure Virtual Network to be peered to the hub
         spoke = vnet.virtual_network(
-            f'spoke{name}', 
+            f'{name}', 
+            props,
             [
                 props.spoke_address_space
             ],
@@ -95,6 +96,7 @@ class Spoke(ComponentResource):
             next_sn = next(subnets)
             spoke_sn = vnet.subnet(
                 stem=f'{name}{s}{subnet[0]}',
+                props=props,
                 virtual_network_name=spoke.name,
                 address_prefix=str(next_sn),
                 route_table_id=spoke_rt.id,
