@@ -2,21 +2,8 @@ from pulumi import ResourceOptions
 import pulumi_azure_native.network as network
 
 
-def bastion_host(stem, virtual_network_name, address_prefix, depends_on=None):
+def bastion_host(stem, ab_snet, depends_on=None):
 
-    # This subnet config needs to be moved over to the Vnet resource
-    ab_sn = network.Subnet(
-        f'bhpi-{stem}',
-        resource_group_name=resource_group_name,
-        name='AzureBastionSubnet',
-        virtual_network_name=virtual_network_name,
-        address_prefix=address_prefix,
-        opts=ResourceOptions(
-            parent=self,
-            delete_before_replace=True,
-            depends_on=depends_on,
-        ),
-    )
     ab_pip = network.PublicIPAddress(
         f'bhpip-{stem}',
         resource_group_name=resource_group_name,
@@ -36,7 +23,7 @@ def bastion_host(stem, virtual_network_name, address_prefix, depends_on=None):
                 id=ab_pip.id,
             ),
             subnet=network.SubnetArgs(
-                id=ab_sn.id,
+                id=ab_snet,
             ),
         )],
         tags=tags,
